IntoLinspace

Trait IntoLinspace 

pub trait IntoLinspace: AsRangedCoord {
    // Provided method
    fn step<S: Clone>(
        self,
        val: S,
    ) -> Linspace<Self::CoordDescType, S, Exact<Self::Value>>
       where Self::Value: Add<S, Output = Self::Value> + PartialOrd + Clone { ... }
}

Provided Methods

fn step<S: Clone>( self, val: S, ) -> Linspace<Self::CoordDescType, S, Exact<Self::Value>>
where Self::Value: Add<S, Output = Self::Value> + PartialOrd + Clone,

Set the step value, make a linspace coordinate from the given range. By default the matching method use the exact match

  • val: The step value
  • *returns: The newly created linspace

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors