ToGroupByRange

Trait ToGroupByRange 

pub trait ToGroupByRange: AsRangedCoord + Sized{
    // Provided method
    fn group_by(
        self,
        value: usize,
    ) -> GroupBy<<Self as AsRangedCoord>::CoordDescType> { ... }
}
The trait that provides method Self::group_by function which creates a GroupBy decorated ranged value.

Provided Methods

fn group_by( self, value: usize, ) -> GroupBy<<Self as AsRangedCoord>::CoordDescType>

Make a grouping ranged value, see the documentation for GroupBy for details.

  • value: The number of values we want to group it
  • return: The newly created grouping range specification

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors