KeyPointHint

Trait KeyPointHint 

pub trait KeyPointHint {
    // Required methods
    fn max_num_points(&self) -> usize;
    fn weight(&self) -> KeyPointWeight;

    // Provided method
    fn bold_points(&self) -> usize { ... }
}
The trait for a hint provided to the key point algorithm used by the coordinate specs. The most important constraint is the max_num_points which means the algorithm could emit no more than specific number of key points weight is used to determine if this is used as a bold grid line or light grid line bold_points returns the max number of coresponding bold grid lines

Required Methods

fn max_num_points(&self) -> usize

Returns the max number of key points

fn weight(&self) -> KeyPointWeight

Returns the weight for this hint

Provided Methods

fn bold_points(&self) -> usize

Returns the point number constraint for the bold points

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl KeyPointHint for usize

Implementors