Drawable

Trait Drawable 

pub trait Drawable<DB: DrawingBackend> {
    // Required method
    fn draw<I: Iterator<Item = BackendCoord>>(
        &self,
        pos: I,
        backend: &mut DB,
        parent_dim: (u32, u32),
    ) -> Result<(), DrawingErrorKind<DB::ErrorType>>;
}
The trait indicates we are able to draw it on a drawing area

Required Methods

fn draw<I: Iterator<Item = BackendCoord>>( &self, pos: I, backend: &mut DB, parent_dim: (u32, u32), ) -> Result<(), DrawingErrorKind<DB::ErrorType>>

Actually draws the element. The key points is already translated into the image coordinate and can be used by DC directly

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'a, Coord, DB: DrawingBackend> Drawable<DB> for BitMapElement<'a, Coord>

Source

impl<'a, Coord: 'a, DB: DrawingBackend, T: Borrow<str>> Drawable<DB> for MultiLineText<'a, Coord, T>

Source

impl<'a, Coord: 'a, DB: DrawingBackend, T: Borrow<str>> Drawable<DB> for Text<'a, Coord, T>

Source

impl<'a, DB: DrawingBackend, Coord: Clone> Drawable<DB> for DynElement<'a, DB, Coord>

Source

impl<Coord, DB: DrawingBackend, A, B> Drawable<DB> for ComposedElement<Coord, DB, A, B>
where for<'a> &'a A: PointCollection<'a, BackendCoord>, for<'b> &'b B: PointCollection<'b, BackendCoord>, A: Drawable<DB>, B: Drawable<DB>,

Source

impl<Coord, DB: DrawingBackend, Size: SizeDesc> Drawable<DB> for Circle<Coord, Size>

Source

impl<Coord, DB: DrawingBackend, Size: SizeDesc> Drawable<DB> for Cross<Coord, Size>

Source

impl<Coord, DB: DrawingBackend, Size: SizeDesc> Drawable<DB> for TriangleMarker<Coord, Size>

Source

impl<Coord, DB: DrawingBackend> Drawable<DB> for EmptyElement<Coord, DB>

Source

impl<Coord, DB: DrawingBackend> Drawable<DB> for PathElement<Coord>

Source

impl<Coord, DB: DrawingBackend> Drawable<DB> for Pixel<Coord>

Source

impl<Coord, DB: DrawingBackend> Drawable<DB> for Polygon<Coord>

Source

impl<Coord, DB: DrawingBackend> Drawable<DB> for Rectangle<Coord>

Source

impl<K, DB: DrawingBackend, O: BoxplotOrient<K, f32>> Drawable<DB> for Boxplot<K, O>

Source

impl<K, V, O: ErrorBarOrient<K, V>, DB: DrawingBackend> Drawable<DB> for ErrorBar<K, V, O>

Source

impl<X, Y: PartialOrd, DB: DrawingBackend> Drawable<DB> for CandleStick<X, Y>