pub trait DefaultValueFormatOption { }Expand description
Since stable Rust doesn’t have specialization, it’s very hard to make our own trait that
automatically implemented the value formatter. This trait uses as a marker indicates if we
should automatically implement the default value formater based on it’s Debug trait
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".